@@ -16,16 +16,16 @@ class DockerService:
     def list_images(self):
         return [
             Image.from_docker_image(di) for di in self.client.images.list()
-            if di.labels.get('app', '') == 'pier'
+            if di.labels.get('app', '') == 'pier' and di.attrs.get('RepoTags')
         ]
 
     def pull_image(self, tag):
         fileobj = io.BytesIO(bytes(f'FROM {tag}', 'utf-8'))
-        self.client.images.build(fileobj=fileobj, tag=tag, labels=self.APP_LABEl)
+        self.client.images.build(fileobj=fileobj, rm=True, tag=tag, labels=self.APP_LABEl)
 
     def build_image(self, tag):
         path = os.path.abspath(os.getcwd())
-        self.client.images.build(path=path, tag=tag, labels=self.APP_LABEl)
+        self.client.images.build(path=path, tag=tag, rm=True, labels=self.APP_LABEl)
 
     def remove_image(self, image):
         try:
